@@ -2189,6 +2189,39 @@ ags_effect_bulk_real_add_plugin(AgsEffectBulk *effect_bulk,
 				gint position,
 				guint create_flags, guint recall_flags)
 {
+  AgsBasePlugin *base_plugin;
+
+  gchar *fallback_filename;
+  
+  base_plugin = NULL;
+
+  fallback_filename = NULL;
+  
+  if(!g_ascii_strncasecmp(plugin_name,
+			  "ags-fx-ladspa",
+			  14)){   
+    base_plugin = ags_ladspa_manager_find_ladspa_plugin_with_fallback(ags_ladspa_manager_get_instance(),
+								      filename, effect);
+  }else if(!g_ascii_strncasecmp(plugin_name,
+				"ags-fx-dssi",
+				12)){
+    base_plugin = ags_dssi_manager_find_dssi_plugin_with_fallback(ags_dssi_manager_get_instance(),
+								  filename, effect);
+  }else if(!g_ascii_strncasecmp(plugin_name,
+				"ags-fx-lv2",
+				11)){
+    base_plugin = ags_lv2_manager_find_lv2_plugin_with_fallback(ags_lv2_manager_get_instance(),
+								filename, effect);
+  }
+
+  if(base_plugin != NULL){
+    g_object_get(base_plugin,
+		 "filename", &fallback_filename,
+		 NULL);
+  }else{
+    fallback_filename = g_strdup(filename);
+  }
+  
   if((AGS_FX_FACTORY_ADD & (create_flags)) != 0){
     if(!g_ascii_strncasecmp(plugin_name,
 			    "ags-fx-ladspa",
@@ -2197,7 +2230,7 @@ ags_effect_bulk_real_add_plugin(AgsEffectBulk *effect_bulk,
 					control_type_name,
 					play_container, recall_container,
 					plugin_name,
-					filename,
+					fallback_filename,
 					effect,
 					start_audio_channel, stop_audio_channel,
 					start_pad, stop_pad,
@@ -2210,7 +2243,7 @@ ags_effect_bulk_real_add_plugin(AgsEffectBulk *effect_bulk,
 				      control_type_name,
 				      play_container, recall_container,
 				      plugin_name,
-				      filename,
+				      fallback_filename,
 				      effect,
 				      start_audio_channel, stop_audio_channel,
 				      start_pad, stop_pad,
@@ -2223,7 +2256,7 @@ ags_effect_bulk_real_add_plugin(AgsEffectBulk *effect_bulk,
 				     control_type_name,
 				     play_container, recall_container,
 				     plugin_name,
-				     filename,
+				     fallback_filename,
 				     effect,
 				     start_audio_channel, stop_audio_channel,
 				     start_pad, stop_pad,
@@ -2240,7 +2273,7 @@ ags_effect_bulk_real_add_plugin(AgsEffectBulk *effect_bulk,
     start_recall = ags_fx_factory_create(effect_bulk->audio,
 					 play_container, recall_container,
 					 plugin_name,
-					 filename,
+					 fallback_filename,
 					 effect,
 					 start_audio_channel, stop_audio_channel,
 					 start_pad, stop_pad,
@@ -2274,6 +2307,8 @@ ags_effect_bulk_real_add_plugin(AgsEffectBulk *effect_bulk,
 
     g_list_free(start_list);
   }
+
+  g_free(fallback_filename);
 }
 
 /**
