@@ -22,7 +22,7 @@
 #include <ags/audio/ags_synth_enums.h>
 #include <ags/audio/ags_audio_signal.h>
 #include <ags/audio/ags_audio_buffer_util.h>
-#include <ags/audio/ags_filter_util.h>
+#include <ags/audio/ags_fast_pitch_util.h>
 
 #include <ags/audio/file/ags_sound_container.h>
 #include <ags/audio/file/ags_sound_resource.h>
@@ -354,11 +354,11 @@ ags_sf2_synth_util_copy_s8(gint8 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_s8(im_buffer,
-			   frame_count,
-			   samplerate,
-			   base_key,
-			   tuning);
+  ags_fast_pitch_util_compute_s8(im_buffer,
+				 frame_count,
+				 samplerate,
+				 base_key,
+				 tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -623,11 +623,11 @@ ags_sf2_synth_util_copy_s16(gint16 *buffer,
 
   tuning = 100.0 * (note - base_key);
 
-  ags_filter_util_pitch_s16(im_buffer,
-			    frame_count,
-			    samplerate,
-			    base_key,
-			    tuning);
+  ags_fast_pitch_util_compute_s16(im_buffer,
+				  frame_count,
+				  samplerate,
+				  base_key,
+				  tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -892,11 +892,11 @@ ags_sf2_synth_util_copy_s24(gint32 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_s24(im_buffer,
-			    frame_count,
-			    samplerate,
-			    base_key,
-			    tuning);
+  ags_fast_pitch_util_compute_s24(im_buffer,
+				  frame_count,
+				  samplerate,
+				  base_key,
+				  tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1161,11 +1161,11 @@ ags_sf2_synth_util_copy_s32(gint32 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_s32(im_buffer,
-			    frame_count,
-			    samplerate,
-			    base_key,
-			    tuning);
+  ags_fast_pitch_util_compute_s32(im_buffer,
+				  frame_count,
+				  samplerate,
+				  base_key,
+				  tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1430,11 +1430,11 @@ ags_sf2_synth_util_copy_s64(gint64 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_s64(im_buffer,
-			    frame_count,
-			    samplerate,
-			    base_key,
-			    tuning);
+  ags_fast_pitch_util_compute_s64(im_buffer,
+				  frame_count,
+				  samplerate,
+				  base_key,
+				  tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1699,11 +1699,11 @@ ags_sf2_synth_util_copy_float(gfloat *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_float(im_buffer,
-			      frame_count,
-			      samplerate,
-			      base_key,
-			      tuning);
+  ags_fast_pitch_util_compute_float(im_buffer,
+				    frame_count,
+				    samplerate,
+				    base_key,
+				    tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1968,11 +1968,11 @@ ags_sf2_synth_util_copy_double(gdouble *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_double(im_buffer,
-			       frame_count,
-			       samplerate,
-			       base_key,
-			       tuning);
+  ags_fast_pitch_util_compute_double(im_buffer,
+				     frame_count,
+				     samplerate,
+				     base_key,
+				     tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -2237,11 +2237,11 @@ ags_sf2_synth_util_copy_complex(AgsComplex *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_filter_util_pitch_complex(im_buffer,
-				frame_count,
-				samplerate,
-				base_key,
-				tuning);
+  ags_fast_pitch_util_compute_complex(im_buffer,
+				      frame_count,
+				      samplerate,
+				      base_key,
+				      tuning);
 
   success = FALSE;
   pong_copy = FALSE;
